"""
@author : hasanaliozkan-dev
"""
from flask import Flask, send_from_directory,render_template #3.1.0
import os
import sys 


app = Flask(__name__)

folder_name = sys.argv[1]


EXAMPLE_FOLDER = folder_name  
ALLOWED_EXTENSIONS = {'py' , 'zip'}  



def allowed_file(filename):
    return '.' in filename and filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS

@app.route('/')
def index():
    try:
        files = [f for f in os.listdir(EXAMPLE_FOLDER) if allowed_file(f)]
        return render_template('file_share.html', files=files)
    except Exception as e:
        app.logger.error(f"Error rendering template: {e}")
        return "Internal Server Error", 500


@app.route('/download/<filename>')
def download_file(filename):

    if allowed_file(filename) and os.path.isfile(os.path.join(EXAMPLE_FOLDER, filename)):
        return send_from_directory(EXAMPLE_FOLDER, filename, as_attachment=True)
    else:
        return "File not found or invalid file type", 404

if __name__ == '__main__':
    app.run(host='0.0.0.0', port=5001)



"""
@author : hasanaliozkan-dev
"""

from flask import Flask, request, render_template
import os
import werkzeug.utils
import sys

app = Flask(__name__)

UPLOAD_FOLDER = sys.argv[1]
ALLOWED_EXTENSIONS = sys.argv[2].split(',')
MULTIPLE_UPLOAD = sys.argv[3] == "True" 
ADD_IP_TO_FILENAME = sys.argv[4] == "True"


app.config['UPLOAD_FOLDER'] = UPLOAD_FOLDER

uploaded_ips = {}

os.makedirs(UPLOAD_FOLDER, exist_ok=True)

def allowed_file(filename):
    return '.' in filename and filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS

@app.route('/', methods=['GET', 'POST'])
def upload_file():
    error_message = None
    client_ip = request.remote_addr 
    allowed_file_str = ', '.join(ALLOWED_EXTENSIONS) 

    
    # Check if the client IP has already uploaded a file
    if not MULTIPLE_UPLOAD and client_ip in uploaded_ips and uploaded_ips[client_ip]:
        error_message = "You can only upload one file per IP address."
        return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)

    if request.method == 'POST':
        # Check if the 'files' part is in the request
        if 'files' not in request.files:
            error_message = "No file part"
            return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)

        files = request.files.getlist('files')  # Get the list of files
        
        if not files:
            error_message = "No selected file"
            return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)


        for file in files:
            if file and allowed_file(file.filename):
                filename = werkzeug.utils.secure_filename(file.filename)
                name, extension = os.path.splitext(filename)
                if ADD_IP_TO_FILENAME:

                    new_filename = f"{name}_{client_ip}{extension}"
                else:
                    new_filename = filename
                file.save(os.path.join(app.config['UPLOAD_FOLDER'], new_filename))
            else:
                error_message = f"File type not allowed. Please upload only {', '.join(ALLOWED_EXTENSIONS)} files."
                return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)

        if not MULTIPLE_UPLOAD:
            uploaded_ips[client_ip] = True
        error_message = f"File(s) uploaded successfully."
        return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)

    
    return render_template("file_gather.html", error_message=error_message,allowed_file=allowed_file_str)



if __name__ == '__main__':
    app.run(host='0.0.0.0', port=5002)



import multiprocessing
import subprocess
class SFSGL():

    def __init__(self, **kwargs):
        self._init_kwargs = kwargs
        self._shared_folder_path = kwargs.get("shared_folder_path", "shared")
        self._gathered_folder_path = kwargs.get("gathered_folder_path", "gathered")
        self._allowed_extension_to_gather = kwargs.get("allowed_extension_to_gather", ["py","zip"])
        self._allowed_extension_to_share = kwargs.get("allowed_extension_to_share", ["py","zip","txt"])
        self._allow_multiple_upload = kwargs.get("allow_multiple_upload", "False")
        self._add_ip_to_file = kwargs.get("add_ip_to_file", "True")
        self._shared_port = kwargs.get("shared_port", 5001)
        self._gathered_port = kwargs.get("gathered_port", 5002)
        
    
    def run_file_gather(self):
        subprocess.run(["python3", "file_gather.py", self._gathered_folder_path, ",".join(self._allowed_extension_to_gather),self._allow_multiple_upload,self._add_ip_to_file])

    def run_file_share(self):
        subprocess.run(["python3", "file_share.py", self._shared_folder_path, ",".join(self._allowed_extension_to_share)])


 
        
    
    def start(self):
        gather_process = multiprocessing.Process(target=self.run_file_gather)
        share_process = multiprocessing.Process(target=self.run_file_share)
        gather_process.start()
        share_process.start()
        gather_process.join()
        share_process.join()
        return self._init_kwargs